@@ -202,6 +202,7 @@ async def docker_registry_client_async(
     docker_registry_secure: DockerRegistrySecure,
     replicate_manifest_lists,
 ) -> DockerRegistryClientAsync:
+    # pylint: disable=unused-argument
     """Provides a DockerRegistryClientAsync instance."""
     # Do not use caching; get a new instance for each test
     async with DockerRegistryClientAsync(
@@ -331,7 +332,7 @@ async def test__get_auth_token_dockerhub():
             )
             assert len(token) > 100
         else:
-            pytest.skip("Unable to retrieve credentials for: %s", endpoint)
+            pytest.skip(f"Unable to retrieve credentials for: {endpoint}")
 
 
 @pytest.mark.online
@@ -363,7 +364,7 @@ async def test__get_auth_token_quay():
             )
             assert len(token) > 100
         else:
-            pytest.skip("Unable to retrieve credentials for: %s", endpoint)
+            pytest.skip(f"Unable to retrieve credentials for: {endpoint}")
 
 
 async def test__get_client_session(
